@@ -10,7 +10,7 @@
    as published by the Free Software Foundation; either version
    2 of the License, or (at your option) any later version.
 */
-/* $Id: ciped.c,v 1.34 2000/07/28 01:12:04 olaf Exp $ */
+/* $Id: ciped.c,v 1.34.4.1 2001/02/11 01:36:10 olaf Exp $ */
 
 #define CTLDIR "/etc/cipe"
 
@@ -763,7 +763,7 @@ int kxchg(int f, int r)
 
     #define kx_typ       (LM->kxbuf[0])
     #define kx_nkind_key (LM->kxbuf+1)
-    #define kx_ts        (*(time_t *)(LM->kxbuf+KEYXCHGTSPOS))
+    #define kx_ts        ntohl(*(time_t *)(LM->kxbuf+KEYXCHGTSPOS))
 #ifdef VER_CRC32
     #define get_kx_nkind_crc(x) memcpy((x), LM->kxbuf+1+userKeySize, 4)
     #define put_kx_nkind_crc(x) memcpy(LM->kxbuf+1+userKeySize, (x), 4)
@@ -794,7 +794,7 @@ int kxchg(int f, int r)
         return 0;
     }
     if (OI(tokxts) && (abs(time(0)-kx_ts)>OI(tokxts))) {
-        dprintf(("KX: timestamp error\n"));
+        logerr(LOG_NOTICE, "KX: timestamp error");
         return 0;
     }
     switch(kx_typ) {
