@@ -10,7 +10,7 @@
    as published by the Free Software Foundation; either version
    2 of the License, or (at your option) any later version.
 */
-/* $Id: sock.c,v 1.27 2000/07/29 00:33:35 olaf Exp $ */
+/* $Id: sock.c,v 1.27.4.1 2001/02/11 01:36:11 olaf Exp $ */
 
 #include "cipe.h"
 
@@ -633,7 +633,7 @@ int cipe_attach(struct NET_DEVICE *dev, struct siocsifcipatt *parm)
 */
 void cipe_fakenkey(struct cipe *c, char typ)
 {
-    int len=sizeof(struct udphdr)+1;
+    int len=sizeof(struct udphdr)+KEYXCHGBLKMIN;
     struct sk_buff *skb=alloc_skb(len, GFP_ATOMIC);
 
     if (!skb) {
@@ -669,6 +669,8 @@ void cipe_fakenkey(struct cipe *c, char typ)
        Since we generate only NK_RREQ and NK_REQ it's effectively
        one _bit_... */
     skb->data[sizeof(struct udphdr)]=typ;
+    (*(__u32 *)(skb->data+sizeof(struct udphdr)+KEYXCHGTSPOS))=
+        htonl(CURRENT_TIME); /* even need timestamp */    
 
     if (sock_queue_rcv_skb(c->sock, skb)<0) {
         printk(KERN_WARNING "%s: cipe_fakenkey: enqueuing failed\n",
